==> kolourpaint_17.12.3.orig.tar.xz: kolourpaint-17.12.3/commands/tools/selection/kpToolSelectionPullFromDocumentCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpToolSelectionPullFromDocumentCommand_H
#define kpToolSelectionPullFromDocumentCommand_H


#include "kpAbstractSelectionContentCommand.h"
#include "imagelib/kpColor.h"


class kpAbstractImageSelection;


class kpToolSelectionPullFromDocumentCommand :
        public kpAbstractSelectionContentCommand
{
public:
    kpToolSelectionPullFromDocumentCommand (
        const kpAbstractImageSelection &originalSelBorder,
        const kpColor &backgroundColor,
        const QString &name,
        kpCommandEnvironment *environ);
    virtual ~kpToolSelectionPullFromDocumentCommand ();

    void execute () Q_DECL_OVERRIDE;
    void unexecute () Q_DECL_OVERRIDE;

private:
    kpColor m_backgroundColor;
};


#endif  // kpToolSelectionPullFromDocumentCommand_H

==> kolourpaint_23.08.5.orig.tar.xz: kolourpaint-23.08.5/commands/tools/selection/kpToolSelectionPullFromDocumentCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpToolSelectionPullFromDocumentCommand_H
#define kpToolSelectionPullFromDocumentCommand_H


#include "kpAbstractSelectionContentCommand.h"
#include "imagelib/kpColor.h"


class kpAbstractImageSelection;


class kpToolSelectionPullFromDocumentCommand :
        public kpAbstractSelectionContentCommand
{
public:
    kpToolSelectionPullFromDocumentCommand (
        const kpAbstractImageSelection &originalSelBorder,
        const kpColor &backgroundColor,
        const QString &name,
        kpCommandEnvironment *environ);
    ~kpToolSelectionPullFromDocumentCommand () override;

    void execute () override;
    void unexecute () override;

private:
    kpColor m_backgroundColor;
};


#endif  // kpToolSelectionPullFromDocumentCommand_H
